pitchtools.DiatonicObject
=========================

.. inheritance-diagram:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.DiatonicObject.DiatonicObject.DiatonicObject.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
